django-memcached-hashring
=========================

A simple Django cache backend based on `python-memcached`_ using hash_ring_
for consistent hashes. See the individual packages' documentation for more
info.

.. _hash_ring: https://github.com/Doist/hash_ring
.. _`python-memcached`: https://github.com/linsomniac/python-memcached
